Class: Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1BatchUpdateResourcePoliciesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappcheck_v1/classes.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb

Overview

Request message for the BatchUpdateResourcePolicies method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppcheckV1BatchUpdateResourcePoliciesRequest

Returns a new instance of GoogleFirebaseAppcheckV1BatchUpdateResourcePoliciesRequest.



205
206
207
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 205

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#requestsArray<Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1UpdateResourcePolicyRequest>

Required. The request messages specifying the ResourcePolicy objects to update. A maximum of 100 objects can be updated in a batch. Corresponds to the JSON property requests



195
196
197
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 195

def requests
  @requests
end

#update_maskString

Optional. A comma-separated list of names of fields in the ResourcePolicy objects to update. Example: enforcement_mode. If this field is present, the update_mask field in the UpdateResourcePolicyRequest messages must all match this field, or the entire batch fails and no updates will be committed. Corresponds to the JSON property updateMask

Returns:

  • (String)


203
204
205
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 203

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



210
211
212
213
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 210

def update!(**args)
  @requests = args[:requests] if args.key?(:requests)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end