Class: Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1BatchUpdateServicesRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappcheck_v1/classes.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb

Overview

Request message for the BatchUpdateServices method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppcheckV1BatchUpdateServicesRequest

Returns a new instance of GoogleFirebaseAppcheckV1BatchUpdateServicesRequest.



253
254
255
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 253

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#requestsArray<Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1UpdateServiceRequest>

Required. The request messages specifying the Services to update. A maximum of 100 objects can be updated in a batch. Corresponds to the JSON property requests



243
244
245
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 243

def requests
  @requests
end

#update_maskString

Optional. A comma-separated list of names of fields in the Services to update. Example: display_name. If the update_mask field is set in both this request and any of the UpdateServiceRequest messages, they must match or the entire batch fails and no updates will be committed. Corresponds to the JSON property updateMask

Returns:

  • (String)


251
252
253
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 251

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



258
259
260
261
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 258

def update!(**args)
  @requests = args[:requests] if args.key?(:requests)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end