Class: Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1DeviceCheckConfig
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1DeviceCheckConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappcheck_v1/classes.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb
Overview
An app's DeviceCheck configuration object. This configuration is used by
ExchangeDeviceCheckToken to validate device tokens issued to apps by
DeviceCheck. It also controls certain properties of the returned
AppCheckToken, such as its ttl. Note that the Team ID registered with your
app is used as part of the validation process. Please register it via the
Firebase Console or programmatically via the Firebase Management Service.
Instance Attribute Summary collapse
-
#key_id ⇒ String
Required.
-
#name ⇒ String
Required.
-
#private_key ⇒ String
Required.
-
#private_key_set ⇒ Boolean
(also: #private_key_set?)
Output only.
-
#token_ttl ⇒ String
Specifies the duration for which App Check tokens exchanged from DeviceCheck tokens will be valid.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1DeviceCheckConfig
constructor
A new instance of GoogleFirebaseAppcheckV1DeviceCheckConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1DeviceCheckConfig
Returns a new instance of GoogleFirebaseAppcheckV1DeviceCheckConfig.
383 384 385 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 383 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key_id ⇒ String
Required. The key identifier of a private key enabled with DeviceCheck,
created in your Apple Developer account.
Corresponds to the JSON property keyId
352 353 354 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 352 def key_id @key_id end |
#name ⇒ String
Required. The relative resource name of the DeviceCheck configuration object,
in the format: `projects/`project_number`/apps/`app_id`/deviceCheckConfig
Corresponds to the JSON propertyname`
359 360 361 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 359 def name @name end |
#private_key ⇒ String
Required. Input only. The contents of the private key (.p8) file associated
with the key specified by key_id. For security reasons, this field will
never be populated in any response.
Corresponds to the JSON property privateKey
366 367 368 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 366 def private_key @private_key end |
#private_key_set ⇒ Boolean Also known as: private_key_set?
Output only. Whether the private_key field was previously set. Since we will
never return the private_key field, this field is the only way to find out
whether it was previously set.
Corresponds to the JSON property privateKeySet
373 374 375 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 373 def private_key_set @private_key_set end |
#token_ttl ⇒ String
Specifies the duration for which App Check tokens exchanged from DeviceCheck
tokens will be valid. If unset, a default value of 1 hour is assumed. Must be
between 30 minutes and 7 days, inclusive.
Corresponds to the JSON property tokenTtl
381 382 383 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 381 def token_ttl @token_ttl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
388 389 390 391 392 393 394 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 388 def update!(**args) @key_id = args[:key_id] if args.key?(:key_id) @name = args[:name] if args.key?(:name) @private_key = args[:private_key] if args.key?(:private_key) @private_key_set = args[:private_key_set] if args.key?(:private_key_set) @token_ttl = args[:token_ttl] if args.key?(:token_ttl) end |