Class: Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1ExchangeAppAttestAssertionRequest
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1ExchangeAppAttestAssertionRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappcheck_v1/classes.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb
Overview
Request message for the ExchangeAppAttestAssertion method.
Instance Attribute Summary collapse
-
#artifact ⇒ String
Required.
-
#assertion ⇒ String
Required.
-
#challenge ⇒ String
Required.
-
#limited_use ⇒ Boolean
(also: #limited_use?)
Specifies whether this attestation is for use in a limited use (
true) or * session based* (false) context.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1ExchangeAppAttestAssertionRequest
constructor
A new instance of GoogleFirebaseAppcheckV1ExchangeAppAttestAssertionRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1ExchangeAppAttestAssertionRequest
Returns a new instance of GoogleFirebaseAppcheckV1ExchangeAppAttestAssertionRequest.
450 451 452 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 450 def initialize(**args) update!(**args) end |
Instance Attribute Details
#artifact ⇒ String
Required. The artifact returned by a previous call to
ExchangeAppAttestAttestation.
Corresponds to the JSON property artifact
NOTE: Values are automatically base64 encoded/decoded in the client library.
425 426 427 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 425 def artifact @artifact end |
#assertion ⇒ String
Required. The CBOR-encoded assertion returned by the client-side App Attest
API.
Corresponds to the JSON property assertion
NOTE: Values are automatically base64 encoded/decoded in the client library.
432 433 434 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 432 def assertion @assertion end |
#challenge ⇒ String
Required. A one-time challenge returned by an immediately prior call to
GenerateAppAttestChallenge.
Corresponds to the JSON property challenge
NOTE: Values are automatically base64 encoded/decoded in the client library.
439 440 441 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 439 def challenge @challenge end |
#limited_use ⇒ Boolean Also known as: limited_use?
Specifies whether this attestation is for use in a limited use (true) or *
session based* (false) context. To enable this attestation to be used with
the replay protection feature, set this to true. The default value is
false.
Corresponds to the JSON property limitedUse
447 448 449 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 447 def limited_use @limited_use end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
455 456 457 458 459 460 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 455 def update!(**args) @artifact = args[:artifact] if args.key?(:artifact) @assertion = args[:assertion] if args.key?(:assertion) @challenge = args[:challenge] if args.key?(:challenge) @limited_use = args[:limited_use] if args.key?(:limited_use) end |