Class: Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1ExchangeAppAttestAttestationRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappcheck_v1/classes.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb

Overview

Request message for the ExchangeAppAttestAttestation method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppcheckV1ExchangeAppAttestAttestationRequest

Returns a new instance of GoogleFirebaseAppcheckV1ExchangeAppAttestAttestationRequest.



477
478
479
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 477

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attestation_statementString

Required. The App Attest statement returned by the client-side App Attest API. This is a base64url encoded CBOR object in the JSON response. Corresponds to the JSON property attestationStatement NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


453
454
455
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 453

def attestation_statement
  @attestation_statement
end

#challengeString

Required. A one-time challenge returned by an immediately prior call to GenerateAppAttestChallenge. Corresponds to the JSON property challenge NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


460
461
462
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 460

def challenge
  @challenge
end

#key_idString

Required. The key ID generated by App Attest for the client app. Corresponds to the JSON property keyId NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


466
467
468
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 466

def key_id
  @key_id
end

#limited_useBoolean Also known as: limited_use?

Specifies whether this attestation is for use in a limited use (true) or * session based* (false) context. To enable this attestation to be used with the replay protection feature, set this to true. The default value is false. Corresponds to the JSON property limitedUse

Returns:

  • (Boolean)


474
475
476
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 474

def limited_use
  @limited_use
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



482
483
484
485
486
487
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 482

def update!(**args)
  @attestation_statement = args[:attestation_statement] if args.key?(:attestation_statement)
  @challenge = args[:challenge] if args.key?(:challenge)
  @key_id = args[:key_id] if args.key?(:key_id)
  @limited_use = args[:limited_use] if args.key?(:limited_use)
end