Class: Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1ExchangeAppAttestAttestationResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappcheck_v1/classes.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb

Overview

Response message for the ExchangeAppAttestAttestation method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppcheckV1ExchangeAppAttestAttestationResponse

Returns a new instance of GoogleFirebaseAppcheckV1ExchangeAppAttestAttestationResponse.



506
507
508
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 506

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_check_tokenGoogle::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1AppCheckToken

Encapsulates an App Check token, which are used to access backend services protected by App Check. Corresponds to the JSON property appCheckToken



498
499
500
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 498

def app_check_token
  @app_check_token
end

#artifactString

An artifact that can be used in future calls to ExchangeAppAttestAssertion. Corresponds to the JSON property artifact NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


504
505
506
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 504

def artifact
  @artifact
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



511
512
513
514
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 511

def update!(**args)
  @app_check_token = args[:app_check_token] if args.key?(:app_check_token)
  @artifact = args[:artifact] if args.key?(:artifact)
end