Class: Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1ExchangeDebugTokenRequest
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1ExchangeDebugTokenRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappcheck_v1/classes.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb
Overview
Request message for the ExchangeDebugToken method.
Instance Attribute Summary collapse
-
#debug_token ⇒ String
Required.
-
#limited_use ⇒ Boolean
(also: #limited_use?)
Specifies whether this attestation is for use in a limited use (
true) or * session based* (false) context.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1ExchangeDebugTokenRequest
constructor
A new instance of GoogleFirebaseAppcheckV1ExchangeDebugTokenRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1ExchangeDebugTokenRequest
Returns a new instance of GoogleFirebaseAppcheckV1ExchangeDebugTokenRequest.
585 586 587 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 585 def initialize(**args) update!(**args) end |
Instance Attribute Details
#debug_token ⇒ String
Required. A debug token secret. This string must match a debug token secret
previously created using CreateDebugToken.
Corresponds to the JSON property debugToken
574 575 576 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 574 def debug_token @debug_token end |
#limited_use ⇒ Boolean Also known as: limited_use?
Specifies whether this attestation is for use in a limited use (true) or *
session based* (false) context. To enable this attestation to be used with
the replay protection feature, set this to true. The default value is
false.
Corresponds to the JSON property limitedUse
582 583 584 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 582 def limited_use @limited_use end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
590 591 592 593 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 590 def update!(**args) @debug_token = args[:debug_token] if args.key?(:debug_token) @limited_use = args[:limited_use] if args.key?(:limited_use) end |