Class: Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1ExchangePlayIntegrityTokenRequest
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1ExchangePlayIntegrityTokenRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappcheck_v1/classes.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb
Overview
Request message for the ExchangePlayIntegrityToken method.
Instance Attribute Summary collapse
-
#limited_use ⇒ Boolean
(also: #limited_use?)
Specifies whether this attestation is for use in a limited use (
true) or * session based* (false) context. -
#play_integrity_token ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1ExchangePlayIntegrityTokenRequest
constructor
A new instance of GoogleFirebaseAppcheckV1ExchangePlayIntegrityTokenRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1ExchangePlayIntegrityTokenRequest
Returns a new instance of GoogleFirebaseAppcheckV1ExchangePlayIntegrityTokenRequest.
647 648 649 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 647 def initialize(**args) update!(**args) end |
Instance Attribute Details
#limited_use ⇒ Boolean Also known as: limited_use?
Specifies whether this attestation is for use in a limited use (true) or *
session based* (false) context. To enable this attestation to be used with
the replay protection feature, set this to true. The default value is
false.
Corresponds to the JSON property limitedUse
637 638 639 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 637 def limited_use @limited_use end |
#play_integrity_token ⇒ String
Required. The integrity verdict response token from Play Integrity issued to
your app.
Corresponds to the JSON property playIntegrityToken
645 646 647 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 645 def play_integrity_token @play_integrity_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
652 653 654 655 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 652 def update!(**args) @limited_use = args[:limited_use] if args.key?(:limited_use) @play_integrity_token = args[:play_integrity_token] if args.key?(:play_integrity_token) end |