Class: Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1ExchangeRecaptchaEnterpriseTokenRequest
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1ExchangeRecaptchaEnterpriseTokenRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappcheck_v1/classes.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb
Overview
Request message for the ExchangeRecaptchaEnterpriseToken method.
Instance Attribute Summary collapse
-
#limited_use ⇒ Boolean
(also: #limited_use?)
Specifies whether this attestation is for use in a limited use (
true) or * session based* (false) context. -
#recaptcha_enterprise_token ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1ExchangeRecaptchaEnterpriseTokenRequest
constructor
A new instance of GoogleFirebaseAppcheckV1ExchangeRecaptchaEnterpriseTokenRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1ExchangeRecaptchaEnterpriseTokenRequest
Returns a new instance of GoogleFirebaseAppcheckV1ExchangeRecaptchaEnterpriseTokenRequest.
678 679 680 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 678 def initialize(**args) update!(**args) end |
Instance Attribute Details
#limited_use ⇒ Boolean Also known as: limited_use?
Specifies whether this attestation is for use in a limited use (true) or *
session based* (false) context. To enable this attestation to be used with
the replay protection feature, set this to true. The default value is
false.
Corresponds to the JSON property limitedUse
668 669 670 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 668 def limited_use @limited_use end |
#recaptcha_enterprise_token ⇒ String
Required. The reCAPTCHA token as returned by the reCAPTCHA Enterprise
JavaScript API.
Corresponds to the JSON property recaptchaEnterpriseToken
676 677 678 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 676 def recaptcha_enterprise_token @recaptcha_enterprise_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
683 684 685 686 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 683 def update!(**args) @limited_use = args[:limited_use] if args.key?(:limited_use) @recaptcha_enterprise_token = args[:recaptcha_enterprise_token] if args.key?(:recaptcha_enterprise_token) end |