Class: Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1PlayIntegrityConfigAccountDetails
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1PlayIntegrityConfigAccountDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappcheck_v1/classes.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb
Overview
A settings object specifying account requirements for Android devices running your app. These settings correspond to requirements on the account details field obtained from the Play Integrity API. See the default responses table for a quick summary. The default values for these settings work for most apps, and are recommended.
Instance Attribute Summary collapse
-
#require_licensed ⇒ Boolean
(also: #require_licensed?)
Specifies whether the caller must have received the
LICENSEDverdict.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1PlayIntegrityConfigAccountDetails
constructor
A new instance of GoogleFirebaseAppcheckV1PlayIntegrityConfigAccountDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1PlayIntegrityConfigAccountDetails
Returns a new instance of GoogleFirebaseAppcheckV1PlayIntegrityConfigAccountDetails.
987 988 989 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 987 def initialize(**args) update!(**args) end |
Instance Attribute Details
#require_licensed ⇒ Boolean Also known as: require_licensed?
Specifies whether the caller must have received the LICENSED verdict.
For additional details about scenarios where your users will receive this
LICENSED label, see the default responses table. If set to true, apps without the
LICENSED app licensing verdict will be rejected. If set to false, any app
licensing verdict is allowed. The default value is false.
Corresponds to the JSON property requireLicensed
984 985 986 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 984 def require_licensed @require_licensed end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
992 993 994 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 992 def update!(**args) @require_licensed = args[:require_licensed] if args.key?(:require_licensed) end |