Class: Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1PlayIntegrityConfigAppIntegrity

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappcheck_v1/classes.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb

Overview

A settings object specifying application integrity requirements for Android devices running your app. These settings correspond to requirements on the ** application integrity** field obtained from the Play Integrity API. See the default responses table for a quick summary. The default values for these settings work for most apps, and are recommended.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppcheckV1PlayIntegrityConfigAppIntegrity

Returns a new instance of GoogleFirebaseAppcheckV1PlayIntegrityConfigAppIntegrity.



1043
1044
1045
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1043

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_unrecognized_versionBoolean Also known as: allow_unrecognized_version?

Specifies whether your running app is allowed to have the UNRECOGNIZED_VERSION app recognition verdict. Note that the app recognition verdict PLAY_RECOGNIZED is a strong, comprehensive integrity signal that takes into account various other signals, including conditional and optional device integrity responses that you have opted into. If your app is published off-Play, this field should be set to true to allow instances of your app installed from off-Play sources to function. If set to false, only PLAY_RECOGNIZED verdicts are allowed, and both UNRECOGNIZED_VERSION and UNEVALUATED will be rejected. If set to true, any app recognition verdict is allowed. The default value is false. Corresponds to the JSON property allowUnrecognizedVersion

Returns:

  • (Boolean)


1040
1041
1042
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1040

def allow_unrecognized_version
  @allow_unrecognized_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1048
1049
1050
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1048

def update!(**args)
  @allow_unrecognized_version = args[:allow_unrecognized_version] if args.key?(:allow_unrecognized_version)
end