Class: Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1UpdateServiceRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappcheck_v1/classes.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb

Overview

Request message for the UpdateService method as well as an individual update message for the BatchUpdateServices method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppcheckV1UpdateServiceRequest

Returns a new instance of GoogleFirebaseAppcheckV1UpdateServiceRequest.



1504
1505
1506
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1504

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#serviceGoogle::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1Service

The enforcement configuration for a Firebase service supported by App Check. Corresponds to the JSON property service



1496
1497
1498
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1496

def service
  @service
end

#update_maskString

Required. A comma-separated list of names of fields in the Service to update. Example: enforcement_mode. Corresponds to the JSON property updateMask

Returns:

  • (String)


1502
1503
1504
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1502

def update_mask
  @update_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1509
1510
1511
1512
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1509

def update!(**args)
  @service = args[:service] if args.key?(:service)
  @update_mask = args[:update_mask] if args.key?(:update_mask)
end