Class: Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1DebugToken

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappcheck_v1/classes.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb

Overview

A debug token is a secret used during the development or integration testing of an app. It essentially allows the development or integration testing to bypass app attestation while still allowing App Check to enforce protection on supported production Firebase services.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppcheckV1DebugToken

Returns a new instance of GoogleFirebaseAppcheckV1DebugToken.



342
343
344
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 342

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Required. A human readable display name used to identify this debug token. Corresponds to the JSON property displayName

Returns:

  • (String)


312
313
314
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 312

def display_name
  @display_name
end

#etagString

Optional. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. This etag is strongly validated as defined by RFC 7232. Corresponds to the JSON property etag

Returns:

  • (String)


320
321
322
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 320

def etag
  @etag
end

#nameString

Required. The relative resource name of the debug token, in the format: projects/`project_number`/apps/`app_id`/debugTokens/`debug_token_id` Corresponds to the JSON property name

Returns:

  • (String)


326
327
328
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 326

def name
  @name
end

#tokenString

Required. Input only. Immutable. The secret token itself. Must be provided during creation, and must be a UUID4, case insensitive. This field is immutable once set, and cannot be provided during an UpdateDebugToken request. You can, however, delete this debug token using DeleteDebugToken to revoke it. For security reasons, this field will never be populated in any response. Corresponds to the JSON property token

Returns:

  • (String)


335
336
337
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 335

def token
  @token
end

#update_timeString

Output only. Timestamp when this debug token was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


340
341
342
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 340

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



347
348
349
350
351
352
353
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 347

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @token = args[:token] if args.key?(:token)
  @update_time = args[:update_time] if args.key?(:update_time)
end