Class: Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1PlayIntegrityConfig
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1PlayIntegrityConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappcheck_v1/classes.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb
Overview
An app's Play Integrity configuration object. This configuration controls
certain properties of the AppCheckToken returned by
ExchangePlayIntegrityToken, such as its ttl. Note that your registered SHA-256
certificate fingerprints are used to validate tokens issued by the Play
Integrity API; please register them via the Firebase Console or
programmatically via the Firebase Management Service.
Instance Attribute Summary collapse
-
#account_details ⇒ Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1PlayIntegrityConfigAccountDetails
A settings object specifying account requirements for Android devices running your app.
-
#app_integrity ⇒ Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1PlayIntegrityConfigAppIntegrity
A settings object specifying application integrity requirements for Android devices running your app.
-
#device_integrity ⇒ Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1PlayIntegrityConfigDeviceIntegrity
A settings object specifying device integrity requirements for Android devices running your app.
-
#name ⇒ String
Required.
-
#token_ttl ⇒ String
Specifies the duration for which App Check tokens exchanged from Play Integrity tokens will be valid.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1PlayIntegrityConfig
constructor
A new instance of GoogleFirebaseAppcheckV1PlayIntegrityConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1PlayIntegrityConfig
Returns a new instance of GoogleFirebaseAppcheckV1PlayIntegrityConfig.
971 972 973 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 971 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_details ⇒ Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1PlayIntegrityConfigAccountDetails
A settings object specifying account requirements for Android devices running
your app. These settings correspond to requirements on the account details
field obtained from the Play Integrity API. See the default
responses table for a quick summary. The default values for these settings work for
most apps, and are recommended.
Corresponds to the JSON property accountDetails
928 929 930 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 928 def account_details @account_details end |
#app_integrity ⇒ Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1PlayIntegrityConfigAppIntegrity
A settings object specifying application integrity requirements for Android
devices running your app. These settings correspond to requirements on the **
application integrity** field obtained from the Play
Integrity API. See the default responses table for a quick summary. The default values
for these settings work for most apps, and are recommended.
Corresponds to the JSON property appIntegrity
939 940 941 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 939 def app_integrity @app_integrity end |
#device_integrity ⇒ Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1PlayIntegrityConfigDeviceIntegrity
A settings object specifying device integrity requirements for Android devices
running your app. These settings correspond to requirements on the device
integrity field obtained from the Play Integrity API. See the
default responses table for a quick summary. Warning: There are also conditional as well
as optional responses that you can receive, but requires
additional explicit opt-in from you. The App Check API is not responsible
for any such opt-ins. The default values for these settings work for most apps,
and are recommended.
Corresponds to the JSON property deviceIntegrity
955 956 957 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 955 def device_integrity @device_integrity end |
#name ⇒ String
Required. The relative resource name of the Play Integrity configuration
object, in the format: projects/`project_number`/apps/`app_id`/
playIntegrityConfig
Corresponds to the JSON property name
962 963 964 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 962 def name @name end |
#token_ttl ⇒ String
Specifies the duration for which App Check tokens exchanged from Play
Integrity tokens will be valid. If unset, a default value of 1 hour is assumed.
Must be between 30 minutes and 7 days, inclusive.
Corresponds to the JSON property tokenTtl
969 970 971 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 969 def token_ttl @token_ttl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
976 977 978 979 980 981 982 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 976 def update!(**args) @account_details = args[:account_details] if args.key?(:account_details) @app_integrity = args[:app_integrity] if args.key?(:app_integrity) @device_integrity = args[:device_integrity] if args.key?(:device_integrity) @name = args[:name] if args.key?(:name) @token_ttl = args[:token_ttl] if args.key?(:token_ttl) end |