Class: Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1PlayIntegrityConfigAccountDetails
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1PlayIntegrityConfigAccountDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappcheck_v1/classes.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb
Overview
A settings object specifying account requirements for Android devices running your app. These settings correspond to requirements on the account details field obtained from the Play Integrity API. See the default responses table for a quick summary. The default values for these settings work for most apps, and are recommended.
Instance Attribute Summary collapse
-
#require_licensed ⇒ Boolean
(also: #require_licensed?)
Specifies whether the caller must have received the
LICENSEDverdict.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1PlayIntegrityConfigAccountDetails
constructor
A new instance of GoogleFirebaseAppcheckV1PlayIntegrityConfigAccountDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1PlayIntegrityConfigAccountDetails
Returns a new instance of GoogleFirebaseAppcheckV1PlayIntegrityConfigAccountDetails.
1007 1008 1009 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1007 def initialize(**args) update!(**args) end |
Instance Attribute Details
#require_licensed ⇒ Boolean Also known as: require_licensed?
Specifies whether the caller must have received the LICENSED verdict.
For additional details about scenarios where your users will receive this
LICENSED label, see the default responses table. If set to true, apps without the
LICENSED app licensing verdict will be rejected. If set to false, any app
licensing verdict is allowed. The default value is false.
Corresponds to the JSON property requireLicensed
1004 1005 1006 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1004 def require_licensed @require_licensed end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1012 1013 1014 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1012 def update!(**args) @require_licensed = args[:require_licensed] if args.key?(:require_licensed) end |