Class: Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1PlayIntegrityConfigDeviceIntegrity
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1PlayIntegrityConfigDeviceIntegrity
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappcheck_v1/classes.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb
Overview
A settings object specifying device integrity requirements for Android devices running your app. These settings correspond to requirements on the device integrity field obtained from the Play Integrity API. See the default responses table for a quick summary. Warning: There are also conditional as well as optional responses that you can receive, but requires additional explicit opt-in from you. The App Check API is not responsible for any such opt-ins. The default values for these settings work for most apps, and are recommended.
Instance Attribute Summary collapse
-
#min_device_recognition_level ⇒ String
Specifies the minimum device integrity level in order for the device to be considered valid.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1PlayIntegrityConfigDeviceIntegrity
constructor
A new instance of GoogleFirebaseAppcheckV1PlayIntegrityConfigDeviceIntegrity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1PlayIntegrityConfigDeviceIntegrity
Returns a new instance of GoogleFirebaseAppcheckV1PlayIntegrityConfigDeviceIntegrity.
1076 1077 1078 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1076 def initialize(**args) update!(**args) end |
Instance Attribute Details
#min_device_recognition_level ⇒ String
Specifies the minimum device integrity level in order for the device to be
considered valid. Any device with a device recognition verdict lower than this
level will be rejected. If this is unspecified, the default level is
NO_INTEGRITY.
Corresponds to the JSON property minDeviceRecognitionLevel
1074 1075 1076 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1074 def min_device_recognition_level @min_device_recognition_level end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1081 1082 1083 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1081 def update!(**args) @min_device_recognition_level = args[:min_device_recognition_level] if args.key?(:min_device_recognition_level) end |