Class: Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1RecaptchaEnterpriseConfig
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1RecaptchaEnterpriseConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappcheck_v1/classes.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb
Overview
An app's reCAPTCHA Enterprise configuration object. This configuration is used
by ExchangeRecaptchaEnterpriseToken to validate reCAPTCHA tokens issued to
apps by reCAPTCHA Enterprise. It also controls certain properties of the
returned AppCheckToken, such as its ttl.
Instance Attribute Summary collapse
-
#name ⇒ String
Required.
-
#risk_analysis ⇒ Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1RecaptchaEnterpriseConfigRiskAnalysis
A settings object specifying risk tolerance and requirements for your application.
-
#site_key ⇒ String
The score-based site key created in reCAPTCHA Enterprise used to invoke reCAPTCHA and generate the reCAPTCHA tokens for your application.
-
#token_ttl ⇒ String
Specifies the duration for which App Check tokens exchanged from reCAPTCHA Enterprise tokens will be valid.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1RecaptchaEnterpriseConfig
constructor
A new instance of GoogleFirebaseAppcheckV1RecaptchaEnterpriseConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1RecaptchaEnterpriseConfig
Returns a new instance of GoogleFirebaseAppcheckV1RecaptchaEnterpriseConfig.
1183 1184 1185 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1183 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Required. The relative resource name of the reCAPTCHA Enterprise configuration
object, in the format: projects/`project_number`/apps/`app_id`/
recaptchaEnterpriseConfig
Corresponds to the JSON property name
1154 1155 1156 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1154 def name @name end |
#risk_analysis ⇒ Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1RecaptchaEnterpriseConfigRiskAnalysis
A settings object specifying risk tolerance and requirements for your
application. These settings correspond to requirements on the *riskAnalysis
* tuple in the assessment obtained from reCAPTCHA
Enterprise. The default values for these settings work for most apps, and are
recommended.
Corresponds to the JSON property riskAnalysis
1164 1165 1166 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1164 def risk_analysis @risk_analysis end |
#site_key ⇒ String
The score-based site key created in reCAPTCHA Enterprise used to
invoke reCAPTCHA and generate the reCAPTCHA tokens for your application.
Important: This is not the site_secret (as it is in reCAPTCHA v3), but
rather your score-based reCAPTCHA Enterprise site key.
Corresponds to the JSON property siteKey
1174 1175 1176 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1174 def site_key @site_key end |
#token_ttl ⇒ String
Specifies the duration for which App Check tokens exchanged from reCAPTCHA
Enterprise tokens will be valid. If unset, a default value of 1 hour is
assumed. Must be between 30 minutes and 7 days, inclusive.
Corresponds to the JSON property tokenTtl
1181 1182 1183 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1181 def token_ttl @token_ttl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1188 1189 1190 1191 1192 1193 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1188 def update!(**args) @name = args[:name] if args.key?(:name) @risk_analysis = args[:risk_analysis] if args.key?(:risk_analysis) @site_key = args[:site_key] if args.key?(:site_key) @token_ttl = args[:token_ttl] if args.key?(:token_ttl) end |