Class: Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1RecaptchaEnterpriseConfigRiskAnalysis

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappcheck_v1/classes.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb

Overview

A settings object specifying risk tolerance and requirements for your application. These settings correspond to requirements on the *riskAnalysis * tuple in the assessment obtained from reCAPTCHA Enterprise. The default values for these settings work for most apps, and are recommended.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppcheckV1RecaptchaEnterpriseConfigRiskAnalysis

Returns a new instance of GoogleFirebaseAppcheckV1RecaptchaEnterpriseConfigRiskAnalysis.



1233
1234
1235
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1233

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#min_valid_scoreFloat

Specifies a minimum score required for a reCAPTCHA token to be considered valid. If its score is greater than or equal to this value, it will be accepted; otherwise, it will be rejected. The value must be between 0.0 and 1.

  1. The default value is 0.5. Corresponds to the JSON property minValidScore

Returns:

  • (Float)


1231
1232
1233
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1231

def min_valid_score
  @min_valid_score
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1238
1239
1240
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1238

def update!(**args)
  @min_valid_score = args[:min_valid_score] if args.key?(:min_valid_score)
end