Class: Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1RecaptchaV3Config
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1RecaptchaV3Config
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappcheck_v1/classes.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb
Overview
An app's reCAPTCHA v3 configuration object. This configuration is used by
ExchangeRecaptchaV3Token to validate reCAPTCHA tokens issued to apps by
reCAPTCHA v3. It also controls certain properties of the returned
AppCheckToken, such as its ttl.
Instance Attribute Summary collapse
-
#min_valid_score ⇒ Float
Specifies a minimum score required for a reCAPTCHA token to be considered valid.
-
#name ⇒ String
Required.
-
#site_secret ⇒ String
Required.
-
#site_secret_set ⇒ Boolean
(also: #site_secret_set?)
Output only.
-
#token_ttl ⇒ String
Specifies the duration for which App Check tokens exchanged from reCAPTCHA tokens will be valid.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1RecaptchaV3Config
constructor
A new instance of GoogleFirebaseAppcheckV1RecaptchaV3Config.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1RecaptchaV3Config
Returns a new instance of GoogleFirebaseAppcheckV1RecaptchaV3Config.
1287 1288 1289 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1287 def initialize(**args) update!(**args) end |
Instance Attribute Details
#min_valid_score ⇒ Float
Specifies a minimum score required for a reCAPTCHA token to be considered valid. If its score is greater than or equal to this value, it will be accepted; otherwise, it will be rejected. The value must be between 0.0 and 1.
- The default value is 0.5.
Corresponds to the JSON property
minValidScore
1256 1257 1258 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1256 def min_valid_score @min_valid_score end |
#name ⇒ String
Required. The relative resource name of the reCAPTCHA v3 configuration object,
in the format: `projects/`project_number`/apps/`app_id`/recaptchaV3Config
Corresponds to the JSON propertyname`
1263 1264 1265 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1263 def name @name end |
#site_secret ⇒ String
Required. Input only. The site secret used to identify your service for
reCAPTCHA v3 verification. For security reasons, this field will never be
populated in any response.
Corresponds to the JSON property siteSecret
1270 1271 1272 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1270 def site_secret @site_secret end |
#site_secret_set ⇒ Boolean Also known as: site_secret_set?
Output only. Whether the site_secret field was previously set. Since we will
never return the site_secret field, this field is the only way to find out
whether it was previously set.
Corresponds to the JSON property siteSecretSet
1277 1278 1279 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1277 def site_secret_set @site_secret_set end |
#token_ttl ⇒ String
Specifies the duration for which App Check tokens exchanged from reCAPTCHA
tokens will be valid. If unset, a default value of 1 day is assumed. Must be
between 30 minutes and 7 days, inclusive.
Corresponds to the JSON property tokenTtl
1285 1286 1287 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1285 def token_ttl @token_ttl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1292 1293 1294 1295 1296 1297 1298 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1292 def update!(**args) @min_valid_score = args[:min_valid_score] if args.key?(:min_valid_score) @name = args[:name] if args.key?(:name) @site_secret = args[:site_secret] if args.key?(:site_secret) @site_secret_set = args[:site_secret_set] if args.key?(:site_secret_set) @token_ttl = args[:token_ttl] if args.key?(:token_ttl) end |