Class: Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1ResourcePolicy

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappcheck_v1/classes.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb

Overview

App Check enforcement policy for a specific resource of a Google service supported by App Check. Note that this policy will override the service-level configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppcheckV1ResourcePolicy

Returns a new instance of GoogleFirebaseAppcheckV1ResourcePolicy.



1349
1350
1351
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1349

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enforcement_modeString

Required. The App Check enforcement mode for this resource. This will override the App Check overall EnforcementMode setting on the service. Corresponds to the JSON property enforcementMode

Returns:

  • (String)


1311
1312
1313
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1311

def enforcement_mode
  @enforcement_mode
end

#etagString

This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up- to-date value before proceeding. This etag is strongly validated as defined by RFC 7232. Corresponds to the JSON property etag

Returns:

  • (String)


1319
1320
1321
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1319

def etag
  @etag
end

#nameString

Required. Identifier. The relative name of the resource policy object, in the format: projects/`project_number`/services/`service_id`/resourcePolicies/` resource_policy_id` Note that the service_id element must be a supported service ID. Currently, the following service IDs are supported: * oauth2. googleapis.com (Google Identity for iOS) resource_policy_id is a system- generated UID. Corresponds to the JSON property name

Returns:

  • (String)


1329
1330
1331
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1329

def name
  @name
end

#target_resourceString

Required. Service specific name of the resource object to which this policy applies, in the format: * iOS OAuth clients (Google Identity for iOS): // oauth2.googleapis.com/projects/project_number/oauthClients/oauth_client_id` Note that the resource must belong to the service specified in thenameand be from the same project as this policy, but the resource is allowed to be missing at the time of creation of this policy; in that case, we make a best- effort attempt at respecting this policy, but it may not have any effect until the resource is fully created. Corresponds to the JSON propertytargetResource`

Returns:

  • (String)


1341
1342
1343
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1341

def target_resource
  @target_resource
end

#update_timeString

Output only. Timestamp when this resource policy configuration object was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1347
1348
1349
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1347

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1354
1355
1356
1357
1358
1359
1360
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1354

def update!(**args)
  @enforcement_mode = args[:enforcement_mode] if args.key?(:enforcement_mode)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @target_resource = args[:target_resource] if args.key?(:target_resource)
  @update_time = args[:update_time] if args.key?(:update_time)
end