Class: Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1Service
- Inherits:
-
Object
- Object
- Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1Service
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebaseappcheck_v1/classes.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb
Overview
The enforcement configuration for a Firebase service supported by App Check.
Instance Attribute Summary collapse
-
#enforcement_mode ⇒ String
Required.
-
#etag ⇒ String
Optional.
-
#name ⇒ String
Required.
-
#replay_protection ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1Service
constructor
A new instance of GoogleFirebaseAppcheckV1Service.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleFirebaseAppcheckV1Service
Returns a new instance of GoogleFirebaseAppcheckV1Service.
1401 1402 1403 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1401 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enforcement_mode ⇒ String
Required. The baseline protection EnforcementMode for this service.
Corresponds to the JSON property enforcementMode
1350 1351 1352 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1350 def enforcement_mode @enforcement_mode end |
#etag ⇒ String
Optional. This checksum is computed by the server based on the value of other
fields, and may be sent on update and delete requests to ensure the client has
an up-to-date value before proceeding. This etag is strongly validated as
defined by RFC 7232.
Corresponds to the JSON property etag
1358 1359 1360 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1358 def etag @etag end |
#name ⇒ String
Required. The relative resource name of the service configuration object, in
the format: projects/`project_number`/services/`service_id` Note that
the service_id element must be a supported service ID. Currently, the
following service IDs are supported. Firebase and Google Cloud services: *
identitytoolkit.googleapis.com (Firebase Authentication) *
firebasedataconnect.googleapis.com (Firebase SQL Connect) * firestore.
googleapis.com (Cloud Firestore) * firebasedatabase.googleapis.com (
Firebase Realtime Database) * firebasestorage.googleapis.com (Cloud Storage
for Firebase) * firebaseml.googleapis.com (Firebase AI Logic) Google Maps
Platform services: * maps-backend.googleapis.com (Maps JavaScript API) *
places.googleapis.com (Places API (New)) Other supported Google services: *
oauth2.googleapis.com (Google Identity for iOS) Note: While all the supported
service_ids may appear to be subdomains of googleapis.com, the service_id
has no semantic meaning beyond identifying the service to App Check. It is
not intended to represent the actual domain to which your apps send traffic,
nor is it necessarily the API that should be enabled to use the service. For
information on using these Google services, consult their documentation.
Corresponds to the JSON property name
1379 1380 1381 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1379 def name @name end |
#replay_protection ⇒ String
Optional. The replay protection EnforcementMode for this service. Note that
this field cannot be set to a level higher than that of baseline protection.
For example, if the enforcement mode for baseline protection is set to
UNENFORCED, this field cannot be set to ENFORCED. In order to enforce
replay protection, you must first enforce App Check's baseline protection. An
HTTP 400 error will be returned in this case. By default, this field is set to
OFF. Setting this field to UNENFORCED or ENFORCED is considered opting
into replay protection. Opting in can impact your requests by adding some
latency and sometimes cost (depending on your attestation provider). To opt
out of replay protection after opting in, set this field to OFF.
Corresponds to the JSON property replayProtection
1393 1394 1395 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1393 def replay_protection @replay_protection end |
#update_time ⇒ String
Output only. Timestamp when this service configuration object was most
recently updated.
Corresponds to the JSON property updateTime
1399 1400 1401 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1399 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1406 1407 1408 1409 1410 1411 1412 |
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1406 def update!(**args) @enforcement_mode = args[:enforcement_mode] if args.key?(:enforcement_mode) @etag = args[:etag] if args.key?(:etag) @name = args[:name] if args.key?(:name) @replay_protection = args[:replay_protection] if args.key?(:replay_protection) @update_time = args[:update_time] if args.key?(:update_time) end |