Class: Google::Apis::FirebaseappcheckV1::GoogleFirebaseAppcheckV1Service

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebaseappcheck_v1/classes.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb,
lib/google/apis/firebaseappcheck_v1/representations.rb

Overview

The enforcement configuration for a Firebase service supported by App Check.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleFirebaseAppcheckV1Service

Returns a new instance of GoogleFirebaseAppcheckV1Service.



1396
1397
1398
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1396

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enforcement_modeString

Required. The baseline protection EnforcementMode for this service. Corresponds to the JSON property enforcementMode

Returns:

  • (String)


1350
1351
1352
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1350

def enforcement_mode
  @enforcement_mode
end

#etagString

Optional. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. This etag is strongly validated as defined by RFC 7232. Corresponds to the JSON property etag

Returns:

  • (String)


1358
1359
1360
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1358

def etag
  @etag
end

#nameString

Required. The relative resource name of the service configuration object, in the format: projects/`project_number`/services/`service_id` Note that the service_id element must be a supported service ID. Currently, the following service IDs are supported. Firebase and Google Cloud services: * identitytoolkit.googleapis.com (Firebase Authentication) * firebasedataconnect.googleapis.com (Firebase SQL Connect) * firestore. googleapis.com (Cloud Firestore) * firebasedatabase.googleapis.com ( Firebase Realtime Database) * firebasestorage.googleapis.com (Cloud Storage for Firebase) * firebaseml.googleapis.com (Firebase AI Logic) Google Maps Platform services: * maps-backend.googleapis.com (Maps JavaScript API) * places.googleapis.com (Places API (New)) Other supported Google services: * oauth2.googleapis.com (Google Identity for iOS) Corresponds to the JSON property name

Returns:

  • (String)


1374
1375
1376
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1374

def name
  @name
end

#replay_protectionString

Optional. The replay protection EnforcementMode for this service. Note that this field cannot be set to a level higher than that of baseline protection. For example, if the enforcement mode for baseline protection is set to UNENFORCED, this field cannot be set to ENFORCED. In order to enforce replay protection, you must first enforce App Check's baseline protection. An HTTP 400 error will be returned in this case. By default, this field is set to OFF. Setting this field to UNENFORCED or ENFORCED is considered opting into replay protection. Opting in can impact your requests by adding some latency and sometimes cost (depending on your attestation provider). To opt out of replay protection after opting in, set this field to OFF. Corresponds to the JSON property replayProtection

Returns:

  • (String)


1388
1389
1390
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1388

def replay_protection
  @replay_protection
end

#update_timeString

Output only. Timestamp when this service configuration object was most recently updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


1394
1395
1396
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1394

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1401
1402
1403
1404
1405
1406
1407
# File 'lib/google/apis/firebaseappcheck_v1/classes.rb', line 1401

def update!(**args)
  @enforcement_mode = args[:enforcement_mode] if args.key?(:enforcement_mode)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @replay_protection = args[:replay_protection] if args.key?(:replay_protection)
  @update_time = args[:update_time] if args.key?(:update_time)
end